@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import os, sys, sqlite3
+import os, sys, sqlite3, re
 from utils.DebugLog import DebugLog, getScriptPath
 from utils.Config import RidesConfig, ConfFile, Ride
 from utils.TrainDb import DbTrain
@@ -21,7 +21,16 @@ class Completer(QCompleter):
       self.model().setStringList(stringlist)
 
    def Filter(self, completionText):
-      filtered=self.stringlist.filter(completionText,Qt.CaseInsensitive)
+      s = unicode(completionText)
+      s = re.sub(u"([âaàä])",  u"[âaàä]", s)
+      s = re.sub(u"([éèêeë])", u"[éèêeë]",s)
+      s = re.sub(u"([iîï])",   u"[iîï]",  s)
+      s = re.sub(u"([uüûù])",  u"[uüûù]", s)
+      s = re.sub(u"([oôö])",   u"[oôö]",  s)
+      s = re.sub(u"([\-\s'])",  u"[\-\s']",  s)
+      r = QtCore.QRegExp(s)
+      r.setCaseSensitivity(Qt.CaseInsensitive)
+      filtered=self.stringlist.filter(r)
       self.model().setStringList(filtered)
 
 class LineEdit(QLineEdit):
